// (c) Copyright Open Text Corporation

using System;
using System.Xml.Serialization;
using System.Collections;
using OpenText.Livelink.Service.Core;
using OpenText.ContentServer.API;

namespace OpenText.Livelink.Service.Hello
{

/// <summary>
/// <para>HelloMessage encapsulates the message returned from the HelloWorld service.</para>
/// </summary>
/// <version>2013-08-26</version>
[Serializable]
[XmlType(Namespace = "urn:Hello.service.livelink.opentext.com")]
public class HelloMessage : ServiceDataObject
{
	private static Log sLog = LogFactory.GetLog( "OpenText.Livelink.Service.Hello.HelloMessage" );

	private HelloGreeting fGreeting;
	private string fMessage;
	private string[] fMessageList;
	private int fNumberOfMessages;

	/// <summary>
	/// <para>Gets or sets the HelloGreeting object.</para>
	/// </summary>
	[XmlElement(IsNullable = false)]
	public HelloGreeting Greeting
	{
		get
		{
			return fGreeting;
		}

		set
		{
			fGreeting = value;
		}
	}

	/// <summary>
	/// <para>Gets or sets the message.</para>
	/// </summary>
	[XmlElement(IsNullable = false)]
	public string Message
	{
		get
		{
			return fMessage;
		}

		set
		{
			fMessage = value;
		}
	}

	/// <summary>
	/// <para>Gets or sets the list of messages.</para>
	/// </summary>
	[XmlElement(IsNullable = false)]
	public string[] MessageList
	{
		get
		{
			return fMessageList;
		}

		set
		{
			fMessageList = value;
		}
	}

	/// <summary>
	/// <para>Gets or sets the number of messages.</para>
	/// </summary>
	[XmlElement(IsNullable = false)]
	public int NumberOfMessages
	{
		get
		{
			return fNumberOfMessages;
		}

		set
		{
			fNumberOfMessages = value;
		}
	}

	public override void load( LLValue value )
	{
		String		featureName = null;

		// Load the parent
		base.load( value );

		try
		{

			featureName = "Greeting";
			fGreeting = (HelloGreeting) SDOUtil.getSDOValue( "?", value.toValue( "Greeting" ) );

			featureName = "Message";
			fMessage = SDOUtil.getStringValue( value.toValue( "Message" ), "Message" );

			featureName = "MessageList";
			LLValue				list = new LLValue();


			list = value.toValue( "MessageList" );
			if ( list.isDefined() )
			{
				fMessageList = new string[ SDOUtil.getSize( list ) ];
				SDOUtil.loadStringList( fMessageList, list );
			}

			featureName = "NumberOfMessages";
			fNumberOfMessages = SDOUtil.getIntegerValue( value.toValue( "NumberOfMessages" ), "NumberOfMessages" );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error loading HelloMessage." + featureName;
			sLog.Error( errMsg );
			sLog.Error( "  LAPI error: " + ex.Message, ex );
			throw new ServiceException( errMsg );
		}
		catch ( ServiceException ex )
		{
			String		errMsg = "Error loading HelloMessage." + featureName;
			sLog.Error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
		catch ( Exception ex )
		{
			String		errMsg = "Error loading HelloMessage." + featureName;
			sLog.Error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
	}

	public override LLValue toLLValue()
	{
		LLValue		value = new LLValue();

		value.setAssoc();

		try
		{
			SDOUtil.setSDOValue( value, "Greeting", fGreeting );
			SDOUtil.setPrimitiveValue( value, "Message", fMessage, LLValue.LL_STRING );
			SDOUtil.setPrimitiveList( value, "MessageList", fMessageList, LLValue.LL_STRING );
			SDOUtil.setPrimitiveValue( value, "NumberOfMessages", fNumberOfMessages, LLValue.LL_INTEGER );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error converting HelloMessage to an LLValue";
			sLog.Error( errMsg );
			sLog.Error( "  LAPI error: " + ex.Message, ex );
			throw new ServiceException( errMsg );
		}

		LLValue	parent = base.toLLValue();

		if ( parent != null )
		{
			IEnumerator nameEnum = parent.GetKeyEnumerator();
			while ( nameEnum.MoveNext() )
			{
				DictionaryEntry entry = (DictionaryEntry) nameEnum.Current;
				String name = ((LLName)entry.Key).toString();
				value.add( name, parent.toValue( name ) );
			}
		}

		// override any _SDOName set in the parent
		value.add( "_SDOName", new LLValue( "Hello.HelloMessage" ) );

		return value;
	}

	public override string ToString()
	{
		System.Text.StringBuilder	sb = new System.Text.StringBuilder();

		sb.Append( "HelloMessage[" );
		sb.Append( "fGreeting=" ).Append( fGreeting ).Append( ",");
		sb.Append( "fMessage=" ).Append( fMessage ).Append( ",");
		sb.Append( "fMessageList=" ).Append( fMessageList ).Append( ",");
		sb.Append( "fNumberOfMessages=" ).Append( fNumberOfMessages ).Append( ",");
		sb.Append( "]" );

		// Output the parent
		sb.Append( base.ToString() );

		return sb.ToString();
	}
}
}
