// (c) Copyright Open Text Corporation

using System;
using System.Configuration;
using System.IO;
using System.ServiceModel;
using System.Xml.Serialization;
using OpenText.Livelink.Service.Core;

namespace OpenText.Livelink.Service.Hello
{

	#region HelloWorld interface
	[ServiceContract( Name = "HelloWorld", Namespace = "urn:Hello.service.livelink.opentext.com" )]
	interface IHelloWorld_WCF
	{
		[OperationContract( Action = "urn:Hello.service.livelink.opentext.com/GetMessage" )]
		[XmlSerializerFormat]
		GetMessageResponse GetMessage( GetMessageRequest request );

	}
	#endregion	// HelloWorld interface

	#region HelloWorld message contract

	[MessageContract( WrapperName = "GetMessage", WrapperNamespace = "urn:Hello.service.livelink.opentext.com", IsWrapped=true )]
	public class GetMessageRequest
	{
		[MessageHeader( Namespace = "urn:api.ecm.opentext.com" )]
		public OTAuthentication OTAuthentication;

		public GetMessageRequest()
		{
		}

		public GetMessageRequest(
			OTAuthentication OTAuthentication )
		{
			this.OTAuthentication = OTAuthentication;
		}
	}

	[MessageContract( WrapperName = "GetMessageResponse", WrapperNamespace = "urn:Hello.service.livelink.opentext.com", IsWrapped=true )]
	public class GetMessageResponse
	{
		[MessageHeader( Namespace = "urn:api.ecm.opentext.com" )]
		public OTAuthentication OTAuthentication;

		[MessageBodyMember( Namespace = "urn:Hello.service.livelink.opentext.com", Order = 0 )]
		public HelloMessage GetMessageResult;

		public GetMessageResponse()
		{
		}

		public GetMessageResponse( HelloMessage GetMessageResult, OTAuthentication authentication )
		{
			this.GetMessageResult = GetMessageResult;
			this.OTAuthentication = authentication;
		}
	}
	#endregion	// HelloWorld message contract

	#region HelloWorld implementation
	[ServiceBehavior( Name = "HelloWorld", Namespace = "urn:Hello.service.livelink.opentext.com" )]
	public class HelloWorld_WCF : IHelloWorld_WCF
	{
		private HelloWorld fService = new HelloWorld();

		public GetMessageResponse GetMessage( GetMessageRequest request )
		{
			HelloMessage result;

			try
			{
				fService.Authentication = request.OTAuthentication;

				result = fService.GetMessage();
			}
			finally
			{
				fService.Authentication = null;
			}

			return new GetMessageResponse( result, request.OTAuthentication );
		}
	}
	#endregion	// HelloWorld implementation
}
